@@ -224,6 +224,7 @@ def test_DOMAIN_RE_context(data, domain):
         b"bbbbb-bbbbbbbbbbbxbbbbbobbbbbrbb.bb",
         b"actor.name",
         b"TRACKERS.one",
+        b"FOREIGN.zip",
     ],
 )
 def test_domain_is_false_positive(domain):
@@ -257,6 +258,8 @@ def test_domain_is_false_positive_real_domain(domain):
         (b"Firstname.Lastname=40example.com", [Node("network.domain", b"example.com", "", 21, 32)]),
         (b"username%2540example.com", [Node("network.domain", b"example.com", "", 13, 24)]),
         (b'=""http:\x00//www.or\x00acle.com\xe2/', []),
+        (b"https://example.com/c9k5y4.zip", [Node("network.domain", b"example.com", "", 8, 19)]),
+        (b"/c9k5y4.zip", []),
     ],
 )
 def test_find_domains(data, domains):
